@@ -1,8 +1,8 @@
 import logging
 
-from fileFormatter import FileFormatter
-from cmdParser import CmdParser
-import log
+from .fileFormatter import FileFormatter
+from .cmdParser import CmdParser
+# import log
 
 
 logger = logging.getLogger('Formatter')
