@@ -1,10 +1,5 @@
-import string
-
-import log
 import logging
 
-import os
-
 logger = logging.getLogger('Formatter')
 
 
